<?php
/**
 * ismoderna Theme Customizer
 *
 * @package ismoderna
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ismoderna_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'ismoderna_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'ismoderna_customize_partial_blogdescription',
			)
		);
		
		
	}
	/* create panel */

		$wp_customize->add_panel( 'ismoderna_theme_option', array(
			'title'    => __( 'Theme Options', 'ismoderna' ),
			'priority' => 1, // Mixed with top-level-section hierarchy.
		) );
		
		/* general section */
		$wp_customize->add_section( 'ismoderna_blog_settings', array(
			'title'      => __( 'Blog Page Settings', 'ismoderna' ),
			'panel'      => 'ismoderna_theme_option',
			'capability' => 'edit_theme_options',
			'priority'   => 35,
		) );
		
		$wp_customize->add_setting( 'blog_content',
		   array(
			  'type'              => 'theme_mod',
			  'default' => '',
			  'sanitize_callback' => 'absint',
			  'capability'        => 'edit_theme_options',
		   )
		);
		
		$wp_customize->add_control( 'blog_content',
		   array(
			  'label' => __( 'Choose content option','ismoderna' ),
			  'section' => 'ismoderna_blog_settings',
			  'priority' => 10,
			  'type' => 'select',
			  'capability' => 'edit_theme_options',
			  'choices' => array( 
				 '1' => __( 'Excerpt','ismoderna' ),
				 '2' => __( 'Full-Content','ismoderna' ),
			  )
		   )
		);
}
add_action( 'customize_register', 'ismoderna_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ismoderna_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ismoderna_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ismoderna_customize_preview_js() {
	wp_enqueue_script( 'ismoderna-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'ismoderna_customize_preview_js' );